
Scikit-HEP
==========

.. image:: https://img.shields.io/pypi/v/scikit-hep.svg
  :alt: PyPI
  :target: https://pypi.python.org/pypi/scikit-hep

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1043949.svg
  :target: https://doi.org/10.5281/zenodo.1043949

.. image:: https://travis-ci.org/scikit-hep/scikit-hep.svg
   :target: https://travis-ci.org/scikit-hep/scikit-hep

.. image:: https://coveralls.io/repos/github/scikit-hep/scikit-hep/badge.svg?branch=master
   :target: https://coveralls.io/github/scikit-hep/scikit-hep?branch=master

Python versions supported:

.. image:: https://img.shields.io/badge/python-2.7-blue.svg
  :target: https://badge.fury.io/py/scikit-hep

.. image:: https://img.shields.io/badge/python-3.4-blue.svg
  :target: https://badge.fury.io/py/scikit-hep

.. image:: https://img.shields.io/badge/python-3.5-blue.svg
  :target: https://badge.fury.io/py/scikit-hep

.. image:: https://img.shields.io/badge/python-3.6-blue.svg
  :target: https://badge.fury.io/py/scikit-hep


Project info
------------

The Scikit-HEP project (http://scikit-hep.org/) is a community-driven and community-oriented project
with the aim of providing Particle Physics at large with a Python package containing core and common tools.
The project started in Autumn 2016 and its packages are actively developed and maintained.

For what concerns the project grand structure, it should be seen as a toolset rather than a toolkit.
It is not just about providing common tools for the community.
It is also about improving on discoverability of utility packages and projects.

Getting in touch
................

There are various ways to
`get in touch <http://scikit-hep.org/get-in-touch.html>`_
with project admins and/or users and developers.

scikit-hep package
------------------

This ``scikit-hep package`` is under redesign, in order to become a metapackage for the project.

Installation
.............

Install ``scikit-hep`` like any other Python package:

.. code-block:: bash

   pip install scikit-hep

or similar (use ``--user``, ``virtualenv``, etc. if you wish).

Strict dependencies
...................

- `Python <http://docs.python-guide.org/en/latest/starting/installation/>`_ (2.7+, 3.4+)
- `Numpy <https://scipy.org/install.html>`_: the numerical library for Python (1.11.0+)
- `matplotlib <https://matplotlib.org/>`_: a popular Python 2D plotting library (> 2.0.0 , < 2.1)


Documentation
.............

The project documentation is hosted on the `Scikit-HEP website`_, and the source code
is in the ``doc/`` folder.

.. _Scikit-HEP website: http://scikit-hep.org/
